using System.Collections;
using API.Controllers;
using API.Service;
using DbContextLib;
using DbDataManager.Service;
using Dto;
using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.Logging.Abstractions;
using ModelToEntities.Business;
using Moq;
using Shared;

namespace TestAPI
{
    public class UserUnitTest
    {
        private readonly Mock<IUserService<UserDTO>> userService;
        public UserUnitTest()
        {
            userService = new Mock<IUserService<UserDTO>>();
        }

        [Fact]
        public void GetUserList()
        {
            //arrange
            var productList = GetUsersData();
            userService.Setup(x => x.GetUsers(1 ,5))
                .Returns(productList);
            var userController = new UserController(new NullLogger<UserController>(), userService.Object);

            //act
            var userResult = userController.GetUsers(1,5);

            if (userResult is OkObjectResult okObjectResult)
            {
                var valeur = okObjectResult.Value;

                Assert.NotNull(valeur); 
                Assert.Equal(GetUsersData().ToString(), valeur.ToString());
                Assert.True(productList.SequenceEqual(valeur as IEnumerable<UserDTO>,));
                
            }

        }



        private List<UserDTO> GetUsersData()
        {
            List<UserDTO> usersData = new List<UserDTO>(3)
            {
                new (
                    0,
                    "Useruser",
                    "motdepasse",
                    "adressemail@gmail.com" ,
                    
                    true
                ),
                new
                (
                    1,
                    "Leuser",
                    "motdepasse",
                    "deuxadresse@gmail.com" ,

                    false
                ),
                new
                (
                    2,
                    "gygyggyg",
                    "ennodlavehc",
                    "thirdadress@gmail.com" ,

                    false
                ),
            };
            return usersData;
        }
    }
}